using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using System.Net;

using System.IO;

namespace Google_Maps_Download
{
    public partial class GMdl_2ndTryDL : Form
    {
        public GMdl_2ndTryDL(DataTable Missing_tiles, mapURL MU)
        {
            InitializeComponent();

            mu = MU;
            
            missing_tiles = Missing_tiles.Copy(); // so removing rows doesn't give an error (works?)

            Grid.DataSource = missing_tiles;
        }

        private DataTable missing_tiles;

        public mapURL mu;

        private WebClient wc = new WebClient();
        private Random ran = new Random();

        private void GiveUp_Click(object sender, EventArgs e)
        {
            string map_name = missing_tiles.Rows[0]["File"].ToString();
            map_name = map_name.Substring(0, map_name.IndexOf("/"));

            StreamWriter sr2 = new StreamWriter(map_name + "/ERROR_LOG.txt", true);

            foreach (DataRow row in missing_tiles.Rows)
            {
                sr2.WriteLine(row["URL"].ToString() + " TO " + row["File"].ToString());
            }

            sr2.Close();

            MessageBox.Show("See ERROR_LOG.txt in the map folder for a list of tiles that were missed");
            this.Close();
        }

        private bool ThumbnailCallback()
        {
            return false;
        }

        private void CheckGoogleSat()
        {
            if (mu.CheckGoogleSatOK() == false)
                MessageBox.Show("Google Satellite tile test failed\n\nMay be an idea to change connection");
        }

        private void TryAgain_Click(object sender, EventArgs e)
        {
            Progress.Visible = true;
            int total = missing_tiles.Rows.Count;
            int count = 0;
            int done_ok = 0;
            int row_num = 0;
            while (row_num < missing_tiles.Rows.Count)
            {
                DataRow row = missing_tiles.Rows[row_num];
                if (WarnOnTileFail.Checked)
                {
                    if (ran.Next(1, 10) == 1)
                    {
                        CheckGoogleSat();
                    }
                }
                count++;
                row_num++;
                Progress.Text = "On tile " + count.ToString() + " out of " + total.ToString() + " got " + done_ok.ToString();
                Application.DoEvents();
                try
                {
                    if (row["URL"].ToString().IndexOf("baidu.com") != -1)
                        new Bitmap(new MemoryStream(wc.DownloadData(row["URL"].ToString()))).GetThumbnailImage(256, 256, new Image.GetThumbnailImageAbort(ThumbnailCallback), System.IntPtr.Zero).Save(row["File"].ToString());
                    else if (row["URL"].ToString().IndexOf("go2map.com") != -1)
                        new Bitmap(new MemoryStream(wc.DownloadData(row["URL"].ToString()))).Save(row["File"].ToString(), System.Drawing.Imaging.ImageFormat.Png);
                    else
                        wc.DownloadFile(row["URL"].ToString(), row["File"].ToString()); // yes, no load balancing...
                    row.Delete();
                    row_num--;

                    done_ok++;
                }
                catch
                {
                    if (WarnOnTileFail.Checked)
                    {
                        CheckGoogleSat();
                    }
                }
            }
            Progress.Visible = false;

            if (missing_tiles.Rows.Count == 0)
            {
                MessageBox.Show("Got all tiles successfully");
                this.Close();
            }
            else
            {
                MessageBox.Show(missing_tiles.Rows.Count.ToString() + " missing tiles still remain (" + total.ToString() + " previously) got " + done_ok.ToString() + ", you may want to try again");
            }
        }

        private void GMdl_2ndTryDL_Load(object sender, EventArgs e)
        {
            if (missing_tiles.Rows[0]["URL"].ToString().IndexOf("http://kh") != -1)
            {
                WarnOnTileFail.Enabled = true;
                WarnOnTileFail.Checked = true;
            }
            else
            {
                WarnOnTileFail.Enabled = false;
                WarnOnTileFail.Checked = false;
            }

            if (WarnOnTileFail.Enabled)
            {
                string page = wc.DownloadString("http://maps.google.com");

                string google_mt = "google.com/mt?n=404&v=";
                int start = page.IndexOf(google_mt);
                while (start != -1)
                {
                    start += google_mt.Length;
                    string google_ver = page.Substring(start, page.IndexOf("&", start) - start);
                    if (google_ver.IndexOf("t") != -1)
                        mu.iTversion = google_ver;
                    else
                        mu.iMversion = google_ver;
                    start = page.IndexOf(google_mt, start);
                }

                string google_s = "google.com/kh?n=404&v=";
                start = page.IndexOf(google_s);
                while (start != -1)
                {
                    start += google_mt.Length;
                    string google_ver = page.Substring(start, page.IndexOf("&", start) - start);
                    mu.iSversion = google_ver;
                    start = page.IndexOf(google_s, start);
                }
            }
        }
    }
}